// SPDX-FileCopyrightText: Contributors to the Power Grid Model project <powergridmodel@lfenergy.org>
//
// SPDX-License-Identifier: MPL-2.0

#pragma once

namespace power_grid_model {

// component list
template <class... T> struct ComponentList {};

} // namespace power_grid_model
